@@ -11,6 +11,8 @@
 
 #include <QGroupBox>
 #include <QListWidget>
+
+#include <KPluginMetaData>
 #include <kservice.h>
 
 class QPushButton;
@@ -27,6 +29,12 @@ public:
     QString localPath;
 };
 
+class PluginListItem : public QListWidgetItem
+{
+public:
+    PluginListItem(const KPluginMetaData &metaData);
+};
+
 /**
  * This widget holds a list of services, with 5 buttons to manage it.
  * It's a separate class so that it can be used by both tabs of the
